# 기여자 서약 행동 강령

## 우리의 서약

우리 구성원, 기여자 및 리더로서 우리는 모든 사람이 나이, 체격, 눈에 보이거나 보이지 않는 장애, 민족성, 성적 특성, 성별 정체성과 표현, 경험 수준, 교육, 사회경제적 지위, 국적, 외모, 인종, 종교 또는 성적 정체성과 성적 지향에 상관없이 우리 커뮤니티에서 괴롭힘 없는 경험을 할 수 있도록 노력할 것을 약속합니다.

우리는 개방적이고 환영하는, 다양하며 포용적이고 건강한 커뮤니티를 조성하는 방식으로 행동하고 상호작용할 것을 약속합니다.

## 우리의 표준

커뮤니티에 긍정적인 환경을 조성하는 행동의 예시는 다음과 같습니다:

* 다른 사람들에게 공감과 친절을 보여주기
* 서로 다른 의견, 관점, 경험을 존중하기
* 건설적인 피드백을 주고, 우아하게 받아들이기
* 실수로 영향을 받은 사람들에게 책임을 지고 사과하며, 그 경험으로부터 배우기

* 개인뿐만 아니라 전체 커뮤니티에 최선의 이익이 되는 것에 집중하기

허용되지 않는 행동의 예시는 다음과 같습니다:

* 성적인 언어나 이미지의 사용, 그리고 어떠한 형태의 성적 관심이나 접근도

* 트롤링, 모욕적이거나 비하하는 댓글, 개인적 또는 정치적 공격  
* 공개적 또는 사적인 괴롭힘  
* 명시적인 허락 없이 물리적 주소나 이메일 주소 등 타인의 개인 정보 공개

* 전문적인 환경에서 부적절하다고 합리적으로 간주될 수 있는 기타 행위

## 시행 책임

커뮤니티 리더는 허용 가능한 행동 기준을 명확히 하고 시행할 책임이 있으며, 부적절하거나 위협적, 공격적, 유해하다고 판단되는 행동에 대해 적절하고 공정한 시정 조치를 취할 것입니다.

커뮤니티 리더는 이 행동 강령과 일치하지 않는 댓글, 커밋, 코드, 위키 편집, 이슈 및 기타 기여를 삭제, 수정 또는 거부할 권리와 책임이 있으며, 적절한 경우 중재 결정 사유를 설명할 것입니다.

## 범위

이 행동 강령은 모든 커뮤니티 공간 내에서 적용되며, 개인이 공식적으로 커뮤니티를 대표하는 공공 장소에서도 적용됩니다.  
커뮤니티를 대표하는 예시로는 공식 이메일 주소 사용, 공식 소셜 미디어 계정을 통한 게시, 온라인 또는 오프라인 행사에서 지정된 대표자로 활동하는 경우 등이 포함됩니다.

## 적용

학대, 괴롭힘 또는 기타 용납할 수 없는 행위의 사례는  
해당 사항을 집행할 책임이 있는 커뮤니티 리더들에게  
aw@funstory.ai 로 신고될 수 있습니다.  
모든 신고는 신속하고 공정하게 검토 및 조사될 것입니다.  

모든 커뮤니티 리더는 어떠한 사건의 신고자에 대한  
개인정보 보호와 안전을 존중할 의무가 있습니다.

## 시행 지침

커뮤니티 리더는 이 행동 강령을 위반한 것으로 간주되는 행위에 대한 결과를 결정할 때 다음 커뮤니티 영향 지침을 따릅니다:

### 1. 수정

**커뮤니티 영향**: 커뮤니티에서 전문적이지 않거나 환영받지 못하는 행동으로 간주되는 부적절한 언어 사용 또는 기타 행위.

**결과**: 커뮤니티 리더로부터 위반 행위의 성격과 해당 행위가 부적절한 이유에 대한 설명을 포함한 개인적인 서면 경고. 공개 사과가 요청될 수 있음.

### 2. 경고

**커뮤니티 영향**: 단일 사건 또는 일련의 행동을 통한 위반.

**결과**: 지속적인 행동에 대한 결과와 함께 경고. 지정된 기간 동안 관련된 사람들과의 상호작용 금지, 이는 행동 강령을 시행하는 사람들과의 원치 않는 상호작용을 포함합니다. 이는 커뮤니티 공간뿐만 아니라 소셜 미디어와 같은 외부 채널에서의 상호작용을 피하는 것을 포함합니다. 이러한 조건을 위반하면 일시적 또는 영구적인 차단으로 이어질 수 있습니다.

### 3. 임시 차단

**커뮤니티 영향**: 커뮤니티 기준을 심각하게 위반하는 행위, 지속적인 부적절한 행동을 포함합니다.

**결과**: 지정된 기간 동안 커뮤니티와의 모든 종류의 상호작용 또는 공개적인 커뮤니케이션에 대한 임시 금지 조치가 적용됩니다. 이 기간 동안 관련된 사람들과의 공개적 또는 비공개적 상호작용, 행동 강령을 시행하는 사람들과의 원치 않는 상호작용은 허용되지 않습니다. 이러한 조건을 위반할 경우 영구적인 금지 조치로 이어질 수 있습니다.

### 4. 영구 정지

**커뮤니티 영향**: 지속적인 부적절한 행동, 개인에 대한 괴롭힘, 또는 특정 집단에 대한 공격 또는 비하를 포함하여 커뮤니티 기준 위반의 패턴을 보여줌.

**결과**: 커뮤니티 내 모든 공개적 상호작용으로부터 영구적 추방.

## 저작자 표시

이 행동 강령은 [Contributor Covenant][homepage]의 2.0 버전을 기반으로 하며,  
https://www.contributor-covenant.org/version/2/0/code_of_conduct.html에서 확인할 수 있습니다.

커뮤니티 영향 가이드라인은 [Mozilla의 행동 강령 시행 단계](https://github.com/mozilla/diversity)에서 영감을 받았습니다.

[homepage]: https://www.contributor-covenant.org

이 행동 강령에 대한 일반적인 질문의 답변은 https://www.contributor-covenant.org/faq의 [FAQ](#자주-묻는-질문)에서 확인할 수 있습니다. 번역은 https://www.contributor-covenant.org/translations에서 제공됩니다.

<div align="right"> 
<h6><small>이 페이지의 일부 내용은 GPT에 의해 번역되었으며 오류가 포함될 수 있습니다.</small></h6>